@@ -50,9 +50,9 @@
 #endif /* !G_ENABLE_DEBUG */
 
 
-/* VOID:STRING (/usr/src/ports/pluma/pluma-1.10.2-1.x86_64/src/pluma-1.10.2/plugins/spell/pluma-spell-marshal.list:1) */
+/* VOID:STRING (/usr/src/ports/pluma/pluma-1.18.1-1.i686/src/pluma-1.18.1/plugins/spell/pluma-spell-marshal.list:1) */
 
-/* VOID:STRING,STRING (/usr/src/ports/pluma/pluma-1.10.2-1.x86_64/src/pluma-1.10.2/plugins/spell/pluma-spell-marshal.list:2) */
+/* VOID:STRING,STRING (/usr/src/ports/pluma/pluma-1.18.1-1.i686/src/pluma-1.18.1/plugins/spell/pluma-spell-marshal.list:2) */
 void
 pluma_marshal_VOID__STRING_STRING (GClosure     *closure,
                                    GValue       *return_value G_GNUC_UNUSED,
@@ -65,9 +65,9 @@ pluma_marshal_VOID__STRING_STRING (GClosure     *closure,
                                                     gpointer     arg_1,
                                                     gpointer     arg_2,
                                                     gpointer     data2);
-  register GMarshalFunc_VOID__STRING_STRING callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_VOID__STRING_STRING callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
 
   g_return_if_fail (n_param_values == 3);
 
@@ -89,7 +89,7 @@ pluma_marshal_VOID__STRING_STRING (GClosure     *closure,
             data2);
 }
 
-/* VOID:STRING,INT (/usr/src/ports/pluma/pluma-1.10.2-1.x86_64/src/pluma-1.10.2/plugins/spell/pluma-spell-marshal.list:3) */
+/* VOID:STRING,INT (/usr/src/ports/pluma/pluma-1.18.1-1.i686/src/pluma-1.18.1/plugins/spell/pluma-spell-marshal.list:3) */
 void
 pluma_marshal_VOID__STRING_INT (GClosure     *closure,
                                 GValue       *return_value G_GNUC_UNUSED,
@@ -102,9 +102,9 @@ pluma_marshal_VOID__STRING_INT (GClosure     *closure,
                                                  gpointer     arg_1,
                                                  gint         arg_2,
                                                  gpointer     data2);
-  register GMarshalFunc_VOID__STRING_INT callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_VOID__STRING_INT callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
 
   g_return_if_fail (n_param_values == 3);
 
@@ -126,7 +126,7 @@ pluma_marshal_VOID__STRING_INT (GClosure     *closure,
             data2);
 }
 
-/* VOID:POINTER (/usr/src/ports/pluma/pluma-1.10.2-1.x86_64/src/pluma-1.10.2/plugins/spell/pluma-spell-marshal.list:4) */
+/* VOID:POINTER (/usr/src/ports/pluma/pluma-1.18.1-1.i686/src/pluma-1.18.1/plugins/spell/pluma-spell-marshal.list:4) */
 
-/* VOID:VOID (/usr/src/ports/pluma/pluma-1.10.2-1.x86_64/src/pluma-1.10.2/plugins/spell/pluma-spell-marshal.list:5) */
+/* VOID:VOID (/usr/src/ports/pluma/pluma-1.18.1-1.i686/src/pluma-1.18.1/plugins/spell/pluma-spell-marshal.list:5) */
 
