@@ -50,7 +50,7 @@
 #endif /* !G_ENABLE_DEBUG */
 
 
-/* BOOLEAN:NONE (/usr/src/ports/pluma/pluma-1.10.2-1.x86_64/src/pluma-1.10.2/pluma/pluma-marshal.list:1) */
+/* BOOLEAN:NONE (/usr/src/ports/pluma/pluma-1.18.1-1.x86_64/src/pluma-1.18.1/pluma/pluma-marshal.list:1) */
 void
 pluma_marshal_BOOLEAN__VOID (GClosure     *closure,
                              GValue       *return_value G_GNUC_UNUSED,
@@ -61,9 +61,9 @@ pluma_marshal_BOOLEAN__VOID (GClosure     *closure,
 {
   typedef gboolean (*GMarshalFunc_BOOLEAN__VOID) (gpointer     data1,
                                                   gpointer     data2);
-  register GMarshalFunc_BOOLEAN__VOID callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_BOOLEAN__VOID callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
   gboolean v_return;
 
   g_return_if_fail (return_value != NULL);
@@ -87,7 +87,7 @@ pluma_marshal_BOOLEAN__VOID (GClosure     *closure,
   g_value_set_boolean (return_value, v_return);
 }
 
-/* BOOLEAN:OBJECT (/usr/src/ports/pluma/pluma-1.10.2-1.x86_64/src/pluma-1.10.2/pluma/pluma-marshal.list:2) */
+/* BOOLEAN:OBJECT (/usr/src/ports/pluma/pluma-1.18.1-1.x86_64/src/pluma-1.18.1/pluma/pluma-marshal.list:2) */
 void
 pluma_marshal_BOOLEAN__OBJECT (GClosure     *closure,
                                GValue       *return_value G_GNUC_UNUSED,
@@ -99,9 +99,9 @@ pluma_marshal_BOOLEAN__OBJECT (GClosure     *closure,
   typedef gboolean (*GMarshalFunc_BOOLEAN__OBJECT) (gpointer     data1,
                                                     gpointer     arg_1,
                                                     gpointer     data2);
-  register GMarshalFunc_BOOLEAN__OBJECT callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_BOOLEAN__OBJECT callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
   gboolean v_return;
 
   g_return_if_fail (return_value != NULL);
@@ -126,9 +126,9 @@ pluma_marshal_BOOLEAN__OBJECT (GClosure     *closure,
   g_value_set_boolean (return_value, v_return);
 }
 
-/* VOID:BOOLEAN (/usr/src/ports/pluma/pluma-1.10.2-1.x86_64/src/pluma-1.10.2/pluma/pluma-marshal.list:3) */
+/* VOID:BOOLEAN (/usr/src/ports/pluma/pluma-1.18.1-1.x86_64/src/pluma-1.18.1/pluma/pluma-marshal.list:3) */
 
-/* VOID:BOOLEAN,POINTER (/usr/src/ports/pluma/pluma-1.10.2-1.x86_64/src/pluma-1.10.2/pluma/pluma-marshal.list:4) */
+/* VOID:BOOLEAN,POINTER (/usr/src/ports/pluma/pluma-1.18.1-1.x86_64/src/pluma-1.18.1/pluma/pluma-marshal.list:4) */
 void
 pluma_marshal_VOID__BOOLEAN_POINTER (GClosure     *closure,
                                      GValue       *return_value G_GNUC_UNUSED,
@@ -141,9 +141,9 @@ pluma_marshal_VOID__BOOLEAN_POINTER (GClosure     *closure,
                                                       gboolean     arg_1,
                                                       gpointer     arg_2,
                                                       gpointer     data2);
-  register GMarshalFunc_VOID__BOOLEAN_POINTER callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_VOID__BOOLEAN_POINTER callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
 
   g_return_if_fail (n_param_values == 3);
 
@@ -165,7 +165,7 @@ pluma_marshal_VOID__BOOLEAN_POINTER (GClosure     *closure,
             data2);
 }
 
-/* VOID:BOXED,BOXED (/usr/src/ports/pluma/pluma-1.10.2-1.x86_64/src/pluma-1.10.2/pluma/pluma-marshal.list:5) */
+/* VOID:BOXED,BOXED (/usr/src/ports/pluma/pluma-1.18.1-1.x86_64/src/pluma-1.18.1/pluma/pluma-marshal.list:5) */
 void
 pluma_marshal_VOID__BOXED_BOXED (GClosure     *closure,
                                  GValue       *return_value G_GNUC_UNUSED,
@@ -178,9 +178,9 @@ pluma_marshal_VOID__BOXED_BOXED (GClosure     *closure,
                                                   gpointer     arg_1,
                                                   gpointer     arg_2,
                                                   gpointer     data2);
-  register GMarshalFunc_VOID__BOXED_BOXED callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_VOID__BOXED_BOXED callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
 
   g_return_if_fail (n_param_values == 3);
 
@@ -202,11 +202,11 @@ pluma_marshal_VOID__BOXED_BOXED (GClosure     *closure,
             data2);
 }
 
-/* VOID:OBJECT (/usr/src/ports/pluma/pluma-1.10.2-1.x86_64/src/pluma-1.10.2/pluma/pluma-marshal.list:6) */
+/* VOID:OBJECT (/usr/src/ports/pluma/pluma-1.18.1-1.x86_64/src/pluma-1.18.1/pluma/pluma-marshal.list:6) */
 
-/* VOID:POINTER (/usr/src/ports/pluma/pluma-1.10.2-1.x86_64/src/pluma-1.10.2/pluma/pluma-marshal.list:7) */
+/* VOID:POINTER (/usr/src/ports/pluma/pluma-1.18.1-1.x86_64/src/pluma-1.18.1/pluma/pluma-marshal.list:7) */
 
-/* VOID:STRING,BOXED,FLAGS (/usr/src/ports/pluma/pluma-1.10.2-1.x86_64/src/pluma-1.10.2/pluma/pluma-marshal.list:8) */
+/* VOID:STRING,BOXED,FLAGS (/usr/src/ports/pluma/pluma-1.18.1-1.x86_64/src/pluma-1.18.1/pluma/pluma-marshal.list:8) */
 void
 pluma_marshal_VOID__STRING_BOXED_FLAGS (GClosure     *closure,
                                         GValue       *return_value G_GNUC_UNUSED,
@@ -220,9 +220,9 @@ pluma_marshal_VOID__STRING_BOXED_FLAGS (GClosure     *closure,
                                                          gpointer     arg_2,
                                                          guint        arg_3,
                                                          gpointer     data2);
-  register GMarshalFunc_VOID__STRING_BOXED_FLAGS callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_VOID__STRING_BOXED_FLAGS callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
 
   g_return_if_fail (n_param_values == 4);
 
@@ -245,7 +245,7 @@ pluma_marshal_VOID__STRING_BOXED_FLAGS (GClosure     *closure,
             data2);
 }
 
-/* VOID:STRING,BOXED,INT,BOOLEAN (/usr/src/ports/pluma/pluma-1.10.2-1.x86_64/src/pluma-1.10.2/pluma/pluma-marshal.list:9) */
+/* VOID:STRING,BOXED,INT,BOOLEAN (/usr/src/ports/pluma/pluma-1.18.1-1.x86_64/src/pluma-1.18.1/pluma/pluma-marshal.list:9) */
 void
 pluma_marshal_VOID__STRING_BOXED_INT_BOOLEAN (GClosure     *closure,
                                               GValue       *return_value G_GNUC_UNUSED,
@@ -260,9 +260,9 @@ pluma_marshal_VOID__STRING_BOXED_INT_BOOLEAN (GClosure     *closure,
                                                                gint         arg_3,
                                                                gboolean     arg_4,
                                                                gpointer     data2);
-  register GMarshalFunc_VOID__STRING_BOXED_INT_BOOLEAN callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_VOID__STRING_BOXED_INT_BOOLEAN callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
 
   g_return_if_fail (n_param_values == 5);
 
@@ -286,9 +286,9 @@ pluma_marshal_VOID__STRING_BOXED_INT_BOOLEAN (GClosure     *closure,
             data2);
 }
 
-/* VOID:UINT,POINTER (/usr/src/ports/pluma/pluma-1.10.2-1.x86_64/src/pluma-1.10.2/pluma/pluma-marshal.list:10) */
+/* VOID:UINT,POINTER (/usr/src/ports/pluma/pluma-1.18.1-1.x86_64/src/pluma-1.18.1/pluma/pluma-marshal.list:10) */
 
-/* VOID:UINT64,UINT64 (/usr/src/ports/pluma/pluma-1.10.2-1.x86_64/src/pluma-1.10.2/pluma/pluma-marshal.list:11) */
+/* VOID:UINT64,UINT64 (/usr/src/ports/pluma/pluma-1.18.1-1.x86_64/src/pluma-1.18.1/pluma/pluma-marshal.list:11) */
 void
 pluma_marshal_VOID__UINT64_UINT64 (GClosure     *closure,
                                    GValue       *return_value G_GNUC_UNUSED,
@@ -301,9 +301,9 @@ pluma_marshal_VOID__UINT64_UINT64 (GClosure     *closure,
                                                     guint64      arg_1,
                                                     guint64      arg_2,
                                                     gpointer     data2);
-  register GMarshalFunc_VOID__UINT64_UINT64 callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_VOID__UINT64_UINT64 callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
 
   g_return_if_fail (n_param_values == 3);
 
@@ -325,9 +325,9 @@ pluma_marshal_VOID__UINT64_UINT64 (GClosure     *closure,
             data2);
 }
 
-/* VOID:VOID (/usr/src/ports/pluma/pluma-1.10.2-1.x86_64/src/pluma-1.10.2/pluma/pluma-marshal.list:12) */
+/* VOID:VOID (/usr/src/ports/pluma/pluma-1.18.1-1.x86_64/src/pluma-1.18.1/pluma/pluma-marshal.list:12) */
 
-/* VOID:INT,INT (/usr/src/ports/pluma/pluma-1.10.2-1.x86_64/src/pluma-1.10.2/pluma/pluma-marshal.list:13) */
+/* VOID:INT,INT (/usr/src/ports/pluma/pluma-1.18.1-1.x86_64/src/pluma-1.18.1/pluma/pluma-marshal.list:13) */
 void
 pluma_marshal_VOID__INT_INT (GClosure     *closure,
                              GValue       *return_value G_GNUC_UNUSED,
@@ -340,9 +340,9 @@ pluma_marshal_VOID__INT_INT (GClosure     *closure,
                                               gint         arg_1,
                                               gint         arg_2,
                                               gpointer     data2);
-  register GMarshalFunc_VOID__INT_INT callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_VOID__INT_INT callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
 
   g_return_if_fail (n_param_values == 3);
 
